@@ -35,14 +35,7 @@ var loop = function () {
     client.end(cb)
   }
 
-  var ops = [
-    connect,
-    simpleQuery,
-    paramsQuery,
-    prepared,
-    sync,
-    end
-  ]
+  var ops = [connect, simpleQuery, paramsQuery, prepared, sync, end]
 
   var start = Date.now()
   async.series(ops, function (err) {
