@@ -17,9 +17,7 @@ describe('reading while not connected', function () {
   it('does not seg fault but does throw execption', function () {
     var client = new Client()
     assert.throws(function () {
-      client.on('notification', function (msg) {
-
-      })
+      client.on('notification', function (msg) {})
     })
   })
 })
